@@ -47,13 +47,13 @@ class Logger:
     def notice(self, msg):
         self.__print("notice", msg)
 
-    def warn(self, msg):
+    def warning(self, msg):
         self.__print("warn", msg)
 
     def error(self, msg):
         self.__print("error", msg)
 
-    def crit(self, msg):
+    def critical(self, msg):
         self.__print("crit", msg)
 
     def alert(self, msg):
@@ -61,13 +61,3 @@ class Logger:
 
     def fatal(self, msg):
         self.__print("fatal", msg)
-
-    @staticmethod
-    def print(msg):
-        """
-        Explicit print option so this can be further controlled later if needed
-
-        :param msg:
-        :return:
-        """
-        print(msg)
