@@ -239,6 +239,14 @@ class URLs:
         # For setting user preferences, not for fetching them. To fetch them, use the "me" call (/api/user-management/me)
         return f"{self.base}/api/user-management/user/{{}}"
 
+    @property
+    def user_create(self):
+        return f"{self.base}/api/user-management/user"
+
+    @property
+    def user_delete(self):
+        return f"{self.base}/api/user-management/user/delete"
+
     @property
     def users(self):
         return f"{self.base}/api/user-management/user/search"
